# Helium::Errors

Simple, stand-alone error object to record and access process failures, whether caused by validation or process.

**This gem has not been completed yet. The instructions in this README are to reference what we're aiming at**

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'helium-errors'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install helium-errors

## Usage

### Basics

Helium::Errors has been design to be as agnostic and flexible as possible. By default, it acts as a simple data struct merely collecting errors:

```
errors = Helium::Errors.new
errors.add(:name, :missing)
errors
  .add(:email, :too_short, min: 3)
  .add(:email, :invalid)

errors
# # Helium::Errors
# |   name: missing
# |   email: too_short (min: 3), invalid
```

### Translations [FUTURE FEATURE]

Errors are stored in a form of pure data, but can be translated onto human-readable messages on request:

```
errors.messages
# {
#   name: [
#     "is required"
#   ],
#    email: [
#     "must be at least 3 characters long",
#     "must be in correct format"
#   ]
# }
```

Errors are using I18n for translations. Additional options can be passed onto `messages` call to modify the outcome. The supported options are:
* `translation_files` - array of paths to i18n translation files
* `locale` - locale to use for translations

```
errors.messages(translation_files: [<path_to_polish_locale>], locale: :pl)
# {
#   name: [
#     "jest wymagane"
#   ],
#    email: [
#     "musi zawierac co najmniej 3 znaki",
#     "musi miec poprawny format"
#   ]
# }
```

### Console

Helium has been designed with console use in mind. Errors will be automatically translated on console inspection.

```
> Errors.new
=> # Helium::Errors: empty

> Errors.new.add(:name, :missing).add(:email, :too_short, min: 3)
=> # Helium::Errors
=> | name: is required
=> | email: must be at least 3 characters long
```

### Configuration

Default translation options behaviour can be changed with:

```
Helium::Errors.configure do |config|
  config.translation_files += [<path_to_polish_locale>, <path_to_spanish_locale>]
  config.locale = :pl
end
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/helium-rb/errors. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [code of conduct](https://github.com/helium-rb/errors/blob/master/CODE_OF_CONDUCT.md).


## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the Helium::Errors project's codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/helium-rb/errors/blob/master/CODE_OF_CONDUCT.md).
